@@ -273,19 +273,16 @@ class JsonList(list):
         with open(file_path, 'w') as f:
             f.write(str(self))
 
-    @classmethod
-    def load_from_file(cls, file_path: str):
+    def load_from_file(self, file_path: str):
         if not path.exists(file_path):
             return None
         json_content = ""
         with open(file_path) as f:
             json_content = f.read()
-        if cls is JsonList:
-            return cls.parse(json_content)
+        return self.parse(json_content)
 
-    @classmethod
-    def load_from_url(cls, uri: str):
+    def load_from_url(self, uri: str):
         req = requests.get(uri)
         if req.status_code == 200:
-            return cls.parse(req.text)
+            return self.parse(req.text)
         return None
